snapshot property

SchemaSnapshot snapshot
final

Desired physical schema used by inspection and migration commands.

Migration creation regenerates the declaration before computing its diff.

Implementation

final SchemaSnapshot snapshot;