DMMF class

Prisma data model meta format(DMMF).

Constructors

DMMF({required DataModel datamodel, required Schema schema, required Mappings mappings, required Map<String, dynamic> source})
const
DMMF.fromJson(Map json)
factory

Properties

datamodel → DataModel
The Data model AST
final
hashCode → int
The hash code for this object.
no setterinherited
mappings → Mappings
The operations map. Derived from the schema.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema → Schema
The query engine API schema.
final
source → Map<String, dynamic>
The DMMF source.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited