DataModel class

Constructors

DataModel({required Iterable<Model> models, required Iterable<DatamodelEnum> enums, required Iterable<Model> types})
const
DataModel.fromJson(Map json)
factory

Properties

enums → Iterable<DatamodelEnum>
final
hashCode → int
The hash code for this object.
no setterinherited
models → Iterable<Model>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
types → Iterable<Model>
composite types
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited