DatamodelEnum class

Constructors

DatamodelEnum({required String name, required Iterable<EnumValue> values, String? dbName, String? documentation})
const
DatamodelEnum.fromJson(Map json)
factory

Properties

dbName → String?
final
documentation → String?
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values → Iterable<EnumValue>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited