InputField class

Constructors

InputField({required String name, required bool isNullable, required bool isRequired, required List<TypeReference> inputTypes, Deprecation? deprecation})
const
InputField.fromJson(Map json)
factory

Properties

deprecation → Deprecation?
final
hashCode → int
The hash code for this object.
no setterinherited
inputTypes → List<TypeReference>
final
isNullable → bool
final
isRequired → bool
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited