InputType class

Constructors

InputType({required String name, required InputTypeConstraints constraints, InputTypeMeta? meta, required List<InputField> fields})
const
InputType.fromJson(Map json)
factory

Properties

constraints → InputTypeConstraints
final
fields → List<InputField>
final
hashCode → int
The hash code for this object.
no setterinherited
meta → InputTypeMeta?
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited