Model class

Constructors

Model({required String name, String? dbName, required Iterable<Field> fields, required Iterable<UniqueIndex> uniqueIndexes, String? documentation, PrimaryKey? primaryKey, required bool isGenerated})
const
Model.fromJson(Map json)
factory

Properties

dbName → String?
final
documentation → String?
final
fields → Iterable<Field>
final
hashCode → int
The hash code for this object.
no setterinherited
isGenerated → bool
final
name → String
final
primaryKey → PrimaryKey?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uniqueIndexes → Iterable<UniqueIndex>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited