ModelMapping class

Constructors

ModelMapping({required String model, required String plural, required Map<ModelAction, String> actions})
const
ModelMapping.fromJson(Map json)
factory

Properties

actions → Map<ModelAction, String>
final
hashCode → int
The hash code for this object.
no setterinherited
model → String
final
plural → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited