OtherOperationMappings class

Constructors

OtherOperationMappings({required Iterable<String> read, required Iterable<String> write})
const
OtherOperationMappings.fromJson(Map json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
read → Iterable<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
write → Iterable<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited