OutputField class

Constructors

OutputField({required String name, required List<InputField> args, required bool isNullable, required TypeReference outputType, Deprecation? deprecation})
const
OutputField.fromJson(Map json)
factory

Properties

args → List<InputField>
final
deprecation → Deprecation?
final
hashCode → int
The hash code for this object.
no setterinherited
isNullable → bool
final
name → String
final
outputType → TypeReference
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited