Schema class

Constructors

Schema({required SchemaTypes<InputType> inputTypes, required SchemaTypes<OutputType> outputTypes, required SchemaTypes<Enum> enumTypes, required SchemaTypes<FieldRefType> fieldRefTypes})
const
Schema.fromJson(Map json)
factory

Properties

enumTypes → SchemaTypes<Enum>
final
fieldRefTypes → SchemaTypes<FieldRefType>
final
hashCode → int
The hash code for this object.
no setterinherited
inputTypes → SchemaTypes<InputType>
final
outputTypes → SchemaTypes<OutputType>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited