TypeReference class

Constructors

TypeReference({required String type, required bool isList, required TypeLocation location, required TypeNamespace? namespace})
const
TypeReference.fromJson(Map json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isList → bool
final
location → TypeLocation
final
namespace → TypeNamespace?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited