statementTimeout property
Honors statement deadlines, potentially by discarding the connection. A timeout does not prove that a submitted write was rolled back.
Implementation
final bool statementTimeout;
Honors statement deadlines, potentially by discarding the connection. A timeout does not prove that a submitted write was rolled back.
final bool statementTimeout;