retryCommit property
bool
get
retryCommit
Retry the same COMMIT only while the adapter confirms the transaction is active.
Implementation
bool get retryCommit;
Retry the same COMMIT only while the adapter confirms the transaction is active.
bool get retryCommit;