retryTransaction property
bool
get
retryTransaction
Whether this failure can be considered for a complete transaction retry.
Implementation
bool get retryTransaction;
Whether this failure can be considered for a complete transaction retry.
bool get retryTransaction;