GenerationException class final

A declaration, generated file or migration source that cannot be processed.

Implemented types

Constructors

GenerationException(String message, {String? code, Uri? source, int? line, int? column})
Creates a source-generation failure with an actionable message.
const

Properties

code String?
Stable diagnostic category for source-level schema errors.
final
column int?
One-based source column, or null for a failure without a source location.
final
hashCode int
The hash code for this object.
no setterinherited
line int?
One-based source line, or null for a failure without a source location.
final
message String
The validation failure, including source location when available.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source Uri?
Source library, when the failure has a declaration.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited