BinaryPaths class

Constructors

BinaryPaths({Map<String, String>? schemaEngine, Map<String, String>? queryEngine, Map<String, String>? libqueryEngine})
const
BinaryPaths.fromJson(Map json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
libqueryEngine → Map<String, String>?
final
queryEngine → Map<String, String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemaEngine → Map<String, String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited