Datasource class

Constructors

Datasource({required String name, required ConnectorType provider, required ConnectorType activeProvider, required Env url, Env? directUrl, required Iterable<String> schemas})
const
Datasource.fromJson(Map json)
factory

Properties

activeProvider → ConnectorType
final
directUrl → Env?
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
provider → ConnectorType
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemas → Iterable<String>
final
url → Env
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited