GeneratorConfig class

Constructors

GeneratorConfig({required String name, Env? output, required bool isCustomOutput, required Env provider, required Map<String, dynamic> config, required Iterable<BinaryTargetsEnvValue> binaryTargets, required Iterable<String> previewFeatures})
const
GeneratorConfig.fromJson(Map json)
factory

Properties

binaryTargets → Iterable<BinaryTargetsEnvValue>
final
config → Map<String, dynamic>
final
hashCode → int
The hash code for this object.
no setterinherited
isCustomOutput → bool
final
name → String
final
output → Env?
final
previewFeatures → Iterable<String>
final
provider → Env
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited