GeneratorOptions class

Constructors

GeneratorOptions({required GeneratorConfig generator, required Iterable<GeneratorConfig> otherGenerators, required String schemaPath, required String schema, required DMMF dmmf, required Iterable<Datasource> datasources, required String version, required BinaryPaths binaryPaths, bool postinstall = false, bool noEngine = false})
const
GeneratorOptions.fromJson(Map json)
factory

Properties

binaryPaths → BinaryPaths
final
datasources → Iterable<Datasource>
final
dmmf → DMMF
final
generator → GeneratorConfig
final
hashCode → int
The hash code for this object.
no setterinherited
noEngine → bool
final
otherGenerators → Iterable<GeneratorConfig>
final
postinstall → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema → String
final
schemaPath → String
final
version → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited