CheckInfo class final

An enforced, validated row CHECK read from this database's catalog.

Constructors

CheckInfo(String? name, String expression)
Records one catalog CHECK without evaluating its expression.
const

Properties

expression String
Catalog SQL expression evaluated by the row CHECK constraint.
final
hashCode int
The hash code for this object.
no setterinherited
name String?
Database constraint name, or null for an unnamed constraint.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited