progress method
Durable step checkpoints, including failed stages of partially applied migrations.
Implementation
Future<List<MigrationProgress>> progress() => loadMigrationProgress(database);
Durable step checkpoints, including failed stages of partially applied migrations.
Future<List<MigrationProgress>> progress() => loadMigrationProgress(database);