cause property
MySQLServerException
cause
final
Original exception with the numeric code and server message.
Implementation
final mysql.MySQLServerException cause;
Original exception with the numeric code and server message.
final mysql.MySQLServerException cause;