GraphQLError class

Constructors

GraphQLError({String? message, String? error, UserFacingError? userFacingError})
Create a new instance of PrismaError.
GraphQLError.fromJson(Map<String, dynamic> json)
Create Prisma error from json.
factory

Properties

error → String?
Prisma error message.
final
hashCode → int
The hash code for this object.
no setterinherited
message → String?
Graphql error message.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userFacingError → UserFacingError?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toException(Engine engine) → PrismaRequestException
Covert Prisma error to PrismaRequestException.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited