TransactionIsolationLevel enum

Isolation level.

Inheritance
Implemented types
Available extensions

Values

readUncommitted → const TransactionIsolationLevel

Read uncommitted.

const TransactionIsolationLevel('ReadUncommitted')
readCommitted → const TransactionIsolationLevel

Read committed.

const TransactionIsolationLevel('ReadCommitted')
repeatableRead → const TransactionIsolationLevel

Repeatable read.

const TransactionIsolationLevel('RepeatableRead')
serializable → const TransactionIsolationLevel

Serializable.

const TransactionIsolationLevel('Serializable')
snapshot → const TransactionIsolationLevel

Snapshot.

const TransactionIsolationLevel('Snapshot')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
originalName → String
String representation.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toGraphQLField() → GraphQLField

Available on PrismaEnum, provided by the PrismaEnumExtension extension

Convert Prisma enum to GraphQL field
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<TransactionIsolationLevel>
A constant List of the values in this enum, in order of their declaration.