UserFacingError class

Constructors

UserFacingError({required String message, String? errorCode})
Create a new instance of UserFacingError.
const
UserFacingError.fromJson(Map<String, dynamic> json)
Create user facing error from json.
factory

Properties

errorCode → String?
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited