Payload class

Prisma event payload.

Implementers

Constructors

Payload({String? target, DateTime? timestamp, required String message})
Create a new event payload.
const
Payload.fromJson(Map<String, dynamic> json)
Create a new event payload from a JSON Map.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
Event message.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target → String?
Event target.
final
timestamp → DateTime?
Event timestamp.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Serialize the event payload to a String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited