QueryPayload class

Query payload.

Inheritance

Constructors

QueryPayload({String? target, DateTime? timestamp, required String query, String? params, Duration? duration})
const
QueryPayload.fromJson(Map<String, dynamic> json)
Create a new query payload from a JSON Map.
factory

Properties

duration → Duration?
Time elapsed (in milliseconds) between client issuing query and database responding
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
Event message.
finalinherited
params → String?
Query parameters
final
query → String
Query sent to the database
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target → String?
Event target.
finalinherited
timestamp → DateTime?
Event timestamp.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Serialize the query payload to a String.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited