PrismaEnum class abstract

Prisma enum

Implemented types
Available extensions

Constructors

PrismaEnum()

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
originalName → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toGraphQLField() → GraphQLField

Available on PrismaEnum, provided by the PrismaEnumExtension extension

Convert Prisma enum to GraphQL field
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited