PrismaException class

Prisma basic exception.

This exception is thrown when an error occurs in any of the prisma engines.

Implemented types
Implementers

Constructors

PrismaException({required String message, Engine? engine})
const

Properties

engine → Engine?
Engine that threw the exception.
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
The exception message.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited