PrismaRequestException class

Prisma request exception.

Inheritance

Constructors

PrismaRequestException({required String message, Engine? engine, String? code})
Create a new instance of PrismaRequestException.
const

Properties

code → String?
A Prisma-specific error code.
final
engine → Engine?
Engine that threw the exception.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
message → String
The exception message.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited