MysqlTransaction class final

MySQL isolation and read-only settings applied to the next transaction.

Inheritance

Constructors

MysqlTransaction({Isolation isolation = Isolation.repeatableRead, bool readOnly = false})
Defaults to repeatable read, independently of prior connection settings.
const

Properties

dialect SqlDialect
Engine these transaction settings are valid for.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
isolation Isolation
Requested MySQL isolation; defaults to repeatable read.
final
readOnly bool
Whether MySQL should reject writes in this transaction.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited