MysqlTransaction constructor
Defaults to repeatable read, independently of prior connection settings.
Implementation
const MysqlTransaction({
this.isolation = Isolation.repeatableRead,
this.readOnly = false,
});
Defaults to repeatable read, independently of prior connection settings.
const MysqlTransaction({
this.isolation = Isolation.repeatableRead,
this.readOnly = false,
});