inTransaction property
bool
get
inTransaction
Whether this view belongs to a transaction or savepoint callback.
Implementation
bool get inTransaction => _transaction;
Whether this view belongs to a transaction or savepoint callback.
bool get inTransaction => _transaction;