Id class final

Includes a field in the primary key, in constructor declaration order.

Constructors

Id({bool generated = false})
Marks a primary-key field. Generated keys may be omitted on creation.
const

Properties

generated → bool
Whether the database generates this single integer-storage key.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited