Index class final

Declares a named index using Dart field names, checked during generation.

Constructors

Index(List<String> fields, {required String name, bool unique = false})
Declares a class-level index.
const

Properties

fields → List<String>
Ordered fields in the index.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
Physical index name.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unique → bool
Whether the index also enforces uniqueness.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited