SqlDeclaration class final

Source metadata for a typed SQL query, created through sqlQuery.

Properties

hashCode int
The hash code for this object.
no setterinherited
mariadb String?
MariaDB SQL file, relative to the declaring Dart library.
final
mysql String?
MySQL SQL file, relative to the declaring Dart library.
final
parameters Record
Named parameter columns, or an empty Record for no parameters.
final
postgres String?
PostgreSQL SQL file, relative to the declaring Dart library.
final
result Record
Named result columns, interpreted by static generation.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sqlite String?
SQLite SQL file, relative to the declaring Dart library.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited