Unique class final

Declares a unique field, or a class-level ordered composite unique key.

Constructors

Unique([List<String> fields = const []])
Declares uniqueness. Strings are checked during generation.
const

Properties

fields → List<String>
Dart field names for class-level usage; empty on a scalar field.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited