custom<T> function

ColumnDefinition<T> custom<T>(
  1. Codec<T> codec, {
  2. String? name,
  3. bool unique = false,
  4. String? defaultSql,
  5. T clientDefault()?,
  6. int? bits,
  7. int? precision,
  8. int? scale,
})

A domain value with a public const codec. Generation reads its storage tag and references its encode/decode functions without executing them. bits constrains integer storage to 16, 32 or 64 bits. precision and scale configure decimal storage; temporal storage accepts precision from 0 to 6. These options describe storage, independently of the Dart type.

Implementation

ColumnDefinition<T> custom<T>(
  Codec<T> codec, {
  String? name,
  bool unique = false,
  String? defaultSql,
  T Function()? clientDefault,
  int? bits,
  int? precision,
  int? scale,
}) => ColumnDefinition<T>._();