index function
Selects a direct column or an ordered positional Record of columns.
The physical name is explicit and does not depend on local variable names.
Implementation
IndexDefinition index(
Object columns, {
required String name,
bool unique = false,
}) => const IndexDefinition._();