integerBits property
Signed integer storage width (16, 32 or 64). The default is 64. This describes the column, not the result width of SQL arithmetic.
Implementation
final int? integerBits;
Signed integer storage width (16, 32 or 64). The default is 64. This describes the column, not the result width of SQL arithmetic.
final int? integerBits;