targetNamespace property
PostgreSQL namespace of the target, independent of its table name. Null retains an unqualified historical target.
Implementation
final String? targetNamespace;
PostgreSQL namespace of the target, independent of its table name. Null retains an unqualified historical target.
final String? targetNamespace;