Change<T>.set constructor
const
Change<T>.set (
- T value
Writes the supplied value, including an explicitly allowed null.
Implementation
const factory Change.set(T value) = _Set<T>;
Writes the supplied value, including an explicitly allowed null.
const factory Change.set(T value) = _Set<T>;