CursorTerm class final

One ordering expression paired with its last-seen, encoded cursor value.

Create terms with a typed expression's cursor method. Nullable expressions require an explicit NullOrder when used for keyset pagination.

Properties

hashCode → int
The hash code for this object.
no setterinherited
order → OrderTerm
SQL ordering whose value is carried by this cursor term.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited