max method
Selects the maximum value, or null for an empty group.
Implementation
Expr<T?> max() =>
Expr.internal(FunctionNode('MAX', [expressionNode]), codec.nullable());
Selects the maximum value, or null for an empty group.
Expr<T?> max() =>
Expr.internal(FunctionNode('MAX', [expressionNode]), codec.nullable());