PlannedColumn typedef

PlannedColumn = ({String codecType, String? column, int index, bool presence, String? table})

A physical SQL output slot, including association keys and presence markers. Expressions without a direct column source have null table/column names.

Implementation

typedef PlannedColumn = ({
  int index,
  String codecType,
  String? table,
  String? column,
  bool presence,
});