skipped property
bool
get
skipped
Whether this load is known to produce no rows without executing SQL.
Implementation
bool get skipped => query == null;
Whether this load is known to produce no rows without executing SQL.
bool get skipped => query == null;