nullable method
Accepts SQL NULL without changing the original codec or physical schema.
Implementation
ResultColumn<T?> nullable() => ResultColumn(name, codec.nullable());
Accepts SQL NULL without changing the original codec or physical schema.
ResultColumn<T?> nullable() => ResultColumn(name, codec.nullable());