map<T> method
Converts decoded values into a record or application model.
Implementation
ResultShape<T> map<T>(T Function(R) mapper) => _MappedResult(this, mapper);
Converts decoded values into a record or application model.
ResultShape<T> map<T>(T Function(R) mapper) => _MappedResult(this, mapper);