Selection<T> constructor
const
Selection<T> ()
Base constructor for typed projections and their Dart result mappings.
Implementation
const Selection();
Base constructor for typed projections and their Dart result mappings.
const Selection();