Selection3<A, B, C> extension

Composes three independently typed selections into one decoded result.

on

Methods

map<R>(R mapper(A, B, C)) Selection<R>

Available on (Selection<A>, Selection<B>, Selection<C>), provided by the Selection3 extension

Maps the three decoded values in Dart after the query executes.