Selection4<A, B, C, D> extension

Composes four independently typed selections into one decoded result.

on

Methods

map<R>(R mapper(A, B, C, D)) Selection<R>

Available on (Selection<A>, Selection<B>, Selection<C>, Selection<D>), provided by the Selection4 extension

Maps the four decoded values in Dart after the query executes.