Selection5<A, B, C, D, E> extension

Composes five independently typed selections into one decoded result.

on

Methods

map<R>(R mapper(A, B, C, D, E)) Selection<R>

Available on (Selection<A>, Selection<B>, Selection<C>, Selection<D>, Selection<E>), provided by the Selection5 extension

Maps the five decoded values in Dart after the query executes.