Selection6<A, B, C, D, E, F> extension

Composes six independently typed selections into one decoded result.

on

Methods

map<R>(R mapper(A, B, C, D, E, F)) Selection<R>

Available on (Selection<A>, Selection<B>, Selection<C>, Selection<D>, Selection<E>, Selection<F>), provided by the Selection6 extension

Maps the six decoded values in Dart after the query executes.