union<G extends Fields> method

Query<R, UnionFields<F>> union<G extends Fields>(
  1. Query<R, G> other
)

Combines SQL scalars or .row projections. Both operands must use this database/session and the same codecs, column types and nullability.

SQL UNION removes duplicate projected rows. Declare ordering on the resulting query when result order matters.

Implementation

Query<R, UnionFields<F>> union<G extends Fields>(Query<R, G> other) =>
    _union(other, all: false);