row property
Selection<R?>
get
row
Selects the complete model row, or null when this alias is absent.
Implementation
Selection<R?> get row => optional(definition.selectRow(fields));
Selects the complete model row, or null when this alias is absent.
Selection<R?> get row => optional(definition.selectRow(fields));