TableRef class final

A table occurrence has nominal identity, even when two row records have the same structural Dart type or a query joins the same physical table twice.

Constructors

TableRef(TableSchema schema)
Creates a distinct occurrence, even when the schema is shared.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema → TableSchema
The physical schema for this occurrence of a table.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited