TableRef constructor
TableRef(
- TableSchema schema
Creates a distinct occurrence, even when the schema is shared.
Implementation
TableRef(this.schema);
Creates a distinct occurrence, even when the schema is shared.
TableRef(this.schema);