maxFractionDigits constant
int
const maxFractionDigits
Maximum count of digits to the right of the decimal point.
Implementation
static const maxFractionDigits = 16383;
Maximum count of digits to the right of the decimal point.
static const maxFractionDigits = 16383;