maxIntegerDigits constant
int
const maxIntegerDigits
Maximum count of digits to the left of the decimal point.
Implementation
static const maxIntegerDigits = 131072;
Maximum count of digits to the left of the decimal point.
static const maxIntegerDigits = 131072;