toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final digits = coefficient.abs().toString(),
      sign = coefficient.isNegative ? '-' : '';
  if (scale <= 0) return '$sign$digits${'0' * -scale}';
  if (scale >= digits.length) {
    return '${sign}0.${'0' * (scale - digits.length)}$digits';
  }
  final split = digits.length - scale;
  return '$sign${digits.substring(0, split)}.${digits.substring(split)}';
}