DecimalRounding enum

Rounding is explicit; exact rejects a non-zero discarded remainder.

Inheritance
Available extensions

Values

exact → const DecimalRounding

Rejects any non-zero discarded remainder.

towardZero → const DecimalRounding

Discards remaining digits without increasing magnitude.

floor → const DecimalRounding

Rounds toward negative infinity.

ceiling → const DecimalRounding

Rounds toward positive infinity.

halfAwayFromZero → const DecimalRounding

Rounds to the nearest value, moving exact ties away from zero.

halfEven → const DecimalRounding

Rounds to the nearest value, choosing an even final digit for exact ties.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DecimalRounding>
A constant List of the values in this enum, in order of their declaration.