CatalogObject class final
A live database object outside the schema features modeled by the ORM.
Constructors
- CatalogObject(String kind, String name, String definition)
-
Records an object that the ORM cannot safely recreate from modeled fields.
const
Properties
- definition → String
-
Catalog SQL or descriptive metadata preserved for manual review.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → String
-
Catalog object category, such as
index,trigger, orview.final - name → String
-
Physical object name, as reported by the catalog reader.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited