MigrationStatus class final

The identifier and recorded fingerprint of one fully applied migration.

Constructors

MigrationStatus(String id, String checksum)
Records a completed history entry without validating a bundled definition.
const

Properties

checksum String
Fingerprint recorded when that migration was applied or baselined.
final
hashCode int
The hash code for this object.
no setterinherited
id String
Identifier of a fully applied migration.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited