RebuildTable class final

SQLite's copy-and-replace operation. Expressions are trusted migration SQL. Both snapshots are after any explicit table/column renames.

Inheritance

Constructors

RebuildTable(TableSchema before, TableSchema after, {required Map<String, String> copy})
Freezes an explicit copy map between two shapes of the same SQLite table.

Properties

after TableSchema
Reviewed replacement shape after copying rows.
final
before TableSchema
Reviewed table shape before copying rows.
final
copy Map<String, String>
Target column names mapped to trusted SQL expressions over the old row.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Stable operation data used in migration checksums and reports.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited