SchemaVerification class final
Differences between a declared snapshot and the live database catalog.
Constructors
-
SchemaVerification(List<
String> differences, List<CatalogObject> unmanaged) -
Records modeled differences and separately reviewable catalog objects.
const
Properties
-
differences
→ List<
String> -
Human-readable mismatches in modeled schema facts.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- matches → bool
-
Equality of the declared schema facts; inspect unmanaged objects separately.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
unmanaged
→ List<
CatalogObject> -
Live objects that require separate review, even when matches is true.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited