WatchQuery<R, F extends Fields> extension
Observe and inspect
Re-executes a root database query after relevant committed changes.
- on
-
- Query<
R, F>
- Query<
Methods
-
watch(
{Iterable< TableSchema> reads = const [], ExecutionOptions options = const ExecutionOptions()}) → Stream<List< R> > -
Available on Query<
Initial snapshot followed by fresh snapshots after relevant committed writes. Add tables hidden inside raw SQL withR, F> , provided by the WatchQuery extensionreads. Read errors are emitted without closing the stream, allowing a later invalidation to retry the query.