PostgresTransaction class final
PostgreSQL isolation and read-only settings for one transaction.
- Inheritance
-
- Object
- TransactionOptions<
Postgres> - PostgresTransaction
Constructors
- PostgresTransaction({Isolation isolation = Isolation.readCommitted, bool readOnly = false})
-
Creates PostgreSQL settings applied by the transaction BEGIN statement.
const
Properties
- dialect → SqlDialect
-
Engine these transaction settings are valid for.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- isolation → Isolation
-
Requested PostgreSQL isolation; defaults to read committed.
final
- readOnly → bool
-
Whether PostgreSQL should reject writes in this transaction.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited