QueryOperation enum
The driver operation measured by a QueryEvent.
Values
- execute → const QueryOperation
-
A complete non-streaming statement, including transaction control SQL.
- cursorOpen → const QueryOperation
-
Opening a database cursor before rows are fetched.
- cursorFetch → const QueryOperation
-
Fetching the next bounded batch from an open cursor.
- cursorClose → const QueryOperation
-
Releasing a cursor and its database resources.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
QueryOperation> - A constant List of the values in this enum, in order of their declaration.