SqliteTransaction class final
SQLite BEGIN mode for an explicit transaction.
- Inheritance
-
- Object
- TransactionOptions<
Sqlite> - SqliteTransaction
Constructors
- SqliteTransaction({SqliteTransactionMode mode = SqliteTransactionMode.deferred})
-
Chooses when SQLite attempts to acquire transaction locks.
const
Properties
- dialect → SqlDialect
-
Engine these transaction settings are valid for.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- mode → SqliteTransactionMode
-
Lock acquisition mode; defaults to SQLite deferred transactions.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited