computed method
Computes the value in the database and excludes it from generated writes. Expressions are trusted SQL using physical column names, never parameters. Computed columns cannot also declare identity or insert defaults.
Implementation
ColumnDefinition<T> computed(
String expression, {
String? sqlite,
String? postgres,
String? mysql,
String? mariadb,
ComputedStorage storage = ComputedStorage.stored,
}) => this;