Ignore class final
Excludes an instance field from persistent scalar mapping.
An ignored constructor parameter must be optional so complete database rows can still instantiate the DTO without inventing a value for it.
Constructors
- Ignore()
-
Marks a nonpersistent field or constructor parameter.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited