IndexSchema class final
A simple index over ordered physical columns.
Constructors
-
IndexSchema(String name, List<
String> columns, {bool unique = false}) -
Describes an index without creating it or inferring sort expressions.
const
Properties
-
columns
→ List<
String> -
Indexed columns in the requested index order.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Physical SQL index name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unique → bool
-
Whether the database enforces uniqueness for this index.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited