alias method
Creates a fresh occurrence of this CTE for a join or self join.
Apply filters before asCte when they must belong to the aliased SQL
definition. Filtering this derived query describes a separate outer query.
Implementation
TableAlias<R, F> alias() => TableAlias.internal(_definition, _cte);