firstOrNull method
Executes the mutation and returns the first returned row, or null if empty.
All matching rows are affected, regardless of how many are returned here.
Implementation
Future<R?> firstOrNull({
ExecutionOptions options = const ExecutionOptions(),
}) async => (await get(options: options)).firstOrNull;