Selection2<A, B> extension
Composes two independently typed selections into one decoded result.
Methods
-
map<
R> (R mapper(A, B)) → Selection< R> -
Available on (Selection<
Maps the two decoded values in Dart without changing their SQL meaning.A> , Selection<B> ), provided by the Selection2 extension