TableAlias<R, F extends Fields> class
final
Explicit aliases support self joins and any number of joins without adding a growing number of generic join-result types.
Properties
-
definition
→ Table<
R, F> -
Physical table and row decoder represented by this occurrence.
final
- fields → F
-
Fields scoped to this occurrence, independent of another alias of the table.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
isPresent
→ Expr<
bool> -
SQL expression testing whether this joined occurrence has a row.
no setter
-
row
→ Selection<
R?> -
Selects the complete model row, or null when this alias is absent.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
nullable<
T> (Expr< T> expression) → Expr<T?> - Decodes a SQL expression as nullable, including an absent left-join value.
-
optional<
T> (Selection< T> selection) → Selection<T?> -
Decodes
selectiononly when this alias is present in a joined row. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited