TextExpression<T extends String?> extension
String operations evaluated by the selected database, preserving SQL NULL.
Matching and case conversion follow database collation and Unicode rules.
- on
-
- Expr<
T>
- Expr<
Methods
-
contains(
String text) → Expr< bool?> -
Available on Expr<
Matches literal text anywhere, escaping LIKE wildcardsT> , provided by the TextExpression extension%,_and!. -
endsWith(
String text) → Expr< bool?> -
Available on Expr<
Matches a literal suffix; LIKE wildcards inT> , provided by the TextExpression extensiontexthave no special meaning. -
like(
String pattern) → Expr< bool?> -
Available on Expr<
Matches a bound SQL LIKE pattern;T> , provided by the TextExpression extension%and_remain wildcards. -
lower(
) → Expr< T> -
Available on Expr<
Converts text to lowercase using database rules, preserving nullability.T> , provided by the TextExpression extension -
startsWith(
String text) → Expr< bool?> -
Available on Expr<
Matches a literal prefix; LIKE wildcards inT> , provided by the TextExpression extensiontexthave no special meaning. -
upper(
) → Expr< T> -
Available on Expr<
Converts text to uppercase using database rules, preserving nullability.T> , provided by the TextExpression extension